@@ -118,7 +118,7 @@ static GtkWidget *build_ui (SimpleFmtxWidget *self)
     priv->button = hildon_button_new(HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
 
     GtkWidget *event_box = gtk_event_box_new();
-    g_signal_connect (event_box, "button-press-event", G_CALLBACK (event_box_clicked), self);
+    g_signal_connect (event_box, "button-release-event", G_CALLBACK (event_box_clicked), self);
 
     hildon_button_set_title((HildonButton*)priv->button, "");
     g_signal_connect (priv->button, "clicked", G_CALLBACK (button_clicked), self);
